@@ -5,10 +5,16 @@ Inspired by http://djangosnippets.org/snippets/2463/
 
 """
 from django.contrib.auth.backends import ModelBackend
-from django.contrib.auth.models import User
 from django.core.validators import validate_email
 
 
+try:
+    from django.contrib.auth import get_user_model
+    User = get_user_model()
+except ImportError:
+    from django.contrib.auth.models import User
+
+
 class EmailBackend(ModelBackend):
     """
     Custom authentication backend that allows to login with an email address.
@@ -32,7 +38,7 @@ class EmailBackend(ModelBackend):
             except User.DoesNotExist:
                 return None
         else:
-            #We have a non-email address username we should try username
+            # We have a non-email address username we should try username
             try:
                 user = User.objects.get(username=username)
             except User.DoesNotExist:
